@@ -1,7 +1,8 @@
 module.exports = {
   options: {
-    // On TravisCI, sometimes the tests that require I/O need extra time.
-    timeout: 10000,
+    // On TravisCI, sometimes the tests that require I/O need extra time
+    // (even more when running in a travis windows worker).
+    timeout: process.env.TRAVIS_OS_NAME === 'windows' ? 20000 : 10000,
     reporter: 'mocha-multi',
     reporterOptions: {
       spec: '-',
